@@ -2,15 +2,15 @@ import re
 import sys
 from collections import namedtuple
 
-from .connection import connect, Connection
+from .connection import connect, Connection, TIMEOUT as DEFAULT_TIMEOUT
 from .cursor import Cursor
 from .pool import create_pool, Pool
 
 
 __all__ = ('connect', 'create_pool', 'Connection', 'Cursor', 'Pool',
-           'version', 'version_info')
+           'version', 'version_info', 'DEFAULT_TIMEOUT')
 
-__version__ = '0.3.2'
+__version__ = '0.4.0'
 
 version = __version__ + ' , Python ' + sys.version
 
@@ -27,7 +27,7 @@ def _parse_version(ver):
         major = int(match.group('major'))
         minor = int(match.group('minor'))
         micro = int(match.group('micro'))
-        levels = {'rc': 'candidate',
+        levels = {'c': 'candidate',
                   'a': 'alpha',
                   'b': 'beta',
                   None: 'final'}
@@ -42,4 +42,4 @@ version_info = _parse_version(__version__)
 
 
 # make pyflakes happy
-(connect, create_pool, Connection, Cursor, Pool)
+(connect, create_pool, Connection, Cursor, Pool, DEFAULT_TIMEOUT)
